Here you can find a bunch of pre-installed configuration files:

* `default.json` - most features included.
* `minimal.json` - create a module with minimal possible features.

You can keep your custom created configuration files at `user` directory.
